@@ -25,6 +25,8 @@
 #define WASMTIME_FEATURE_ASYNC
 #define WASMTIME_FEATURE_CRANELIFT
 #define WASMTIME_FEATURE_WINCH
+#define WASMTIME_FEATURE_DEBUG_BUILTINS
+#define WASMTIME_FEATURE_POOLING_ALLOCATOR
 // ... if you add a line above this be sure to change the other locations
 // marked WASMTIME_FEATURE_LIST
 
